# ozi-spec CHANGELOG
## 0.20.1 (2025-01-26)


### Build system


* build(deps): bump step-security/harden-runner from 2.10.3 to 2.10.4

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.3 to 2.10.4.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c95a14d0e5bab51a9f56296a4eb0e416910cd350...cb605e52c26070c328afc4562f0b4ada7618a84e)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`698a8d0`](https://github.com/OZI-Project/ozi-spec/commit/698a8d00f42e6f09f7714a670373a86ac5432c90))

* build: update release endpoints to support cibuildwheel — rjdbcm <rjdbcm@outlook.com>
([`242103f`](https://github.com/OZI-Project/ozi-spec/commit/242103f5c91663cf03a0d07bc7d65807c0f5850d))

## 0.20.0 (2025-01-15)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.5.3 to 1.5.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.3 to 1.5.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.3...1.5.4)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ac3db6a`](https://github.com/OZI-Project/ozi-spec/commit/ac3db6abeca81346ead221c9a3bd879dac28c419))

* build(deps): bump OZI-Project/draft from 1.8.0 to 1.9.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.8.0...1.9.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1848b8a`](https://github.com/OZI-Project/ozi-spec/commit/1848b8adc0a29b9a6c210df2d1e484a60bdf0a55))

* build(deps): bump OZI-Project/publish from 1.7.3 to 1.8.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.3 to 1.8.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.3...1.8.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0e4d2a5`](https://github.com/OZI-Project/ozi-spec/commit/0e4d2a597a4319660382a8d6462d1ab825196c11))


### Features


* feat: semantic-release~=9.16

build(deps): bump OZI-Project/draft from 1.8.0 to 1.9.0
([`e262f82`](https://github.com/OZI-Project/ozi-spec/commit/e262f82f0c9963bd3813b395114290ecb153ec34))

## 0.19.0 (2025-01-13)

## 0.18.2 (2025-01-09)


### Build system


* build(deps): bump OZI-Project/release from 1.2.1 to 1.3.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.2.1 to 1.3.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.2.1...1.3.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`09c1b3e`](https://github.com/OZI-Project/ozi-spec/commit/09c1b3e5a08c3c784a64c8421fe6efbe4d3f2c99))

* build(deps): bump step-security/harden-runner from 2.10.2 to 2.10.3

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.2 to 2.10.3.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0080882f6c36860b6ba35c610c98ce87d4e2f26f...c95a14d0e5bab51a9f56296a4eb0e416910cd350)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ecc749b`](https://github.com/OZI-Project/ozi-spec/commit/ecc749be2dde0e89f25d34521f3e3b5f6d6d3bd5))

* build(deps): bump OZI-Project/checkpoint from 1.5.1 to 1.5.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.1 to 1.5.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.5.1...1.5.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`677be40`](https://github.com/OZI-Project/ozi-spec/commit/677be40f7ca8355f78fae5b8bb9ee160741a3652))


### Features


* feat: OZI-Project/release 1.3 - support wrap-file OZI subproject
([`e0fa02a`](https://github.com/OZI-Project/ozi-spec/commit/e0fa02a8e12a434855c014281bccac37f923b7bf))

## 0.18.1 (2025-01-05)


### Build system


* build(deps): bump OZI-Project/draft from 1.7.0 to 1.8.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.7.0 to 1.8.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.7.0...1.8.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`015290e`](https://github.com/OZI-Project/ozi-spec/commit/015290e9484ce451dbe52f552528c49e4a0cb52f))

* build(deps): bump OZI-Project/publish from 1.7.2 to 1.7.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.2...1.7.3)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6b28e95`](https://github.com/OZI-Project/ozi-spec/commit/6b28e9554cfa3ec74bf8f0c6daf27f8fe47c91a5))

* build(deps): bump OZI-Project/release from 1.1.2 to 1.2.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.2 to 1.2.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.1.2...1.2.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e4c1b2f`](https://github.com/OZI-Project/ozi-spec/commit/e4c1b2f621df539b2a52801a9ea12c09b1dd5d7a))

* build(deps): bump OZI-Project/checkpoint from 1.4.0 to 1.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.4.0 to 1.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.4.0...1.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c02dd9a`](https://github.com/OZI-Project/ozi-spec/commit/c02dd9a7dcf4bfcd58a9c78fafa832000402432a))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bcc91c2`](https://github.com/OZI-Project/ozi-spec/commit/bcc91c246ca0e2c75a222d7091eaf519a8331de4))

## 0.18.0 (2025-01-01)

## 0.17.1 (2024-12-30)

## 0.17.0 (2024-12-30)


### Bug fixes


* fix: ci module missing from build — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9115a15`](https://github.com/OZI-Project/ozi-spec/commit/9115a1540ad9db9ad27471f2680831cf0bc343bd))

* fix: remove duplicate license data — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6a49f7a`](https://github.com/OZI-Project/ozi-spec/commit/6a49f7a5769be287241d3d891c52a1eb7bdf4adf))


### Build system


* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8688a4c`](https://github.com/OZI-Project/ozi-spec/commit/8688a4c31584b90eb26f39564f0100f18d22eec4))

* build: use pyproject build version in API — rjdbcm <rjdbcm@outlook.com>
([`88f5c39`](https://github.com/OZI-Project/ozi-spec/commit/88f5c398151f4a630842d17daacc5578e352fa38))

* build(deps): update ozi-build[core,uv] requirement


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2386aa2`](https://github.com/OZI-Project/ozi-spec/commit/2386aa2b8403cd229637c06112ad89f7a564bf7f))


### Features


* feat: OZI.build 1.10 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a6fed56`](https://github.com/OZI-Project/ozi-spec/commit/a6fed563ebb1afde3d9831a2b1d7a38aa68e8d93))

* feat: OZI.build 1.9

build(deps): update ozi-build[core,uv] requirement from ~=1.8.0 to ~=1.9.2
([`9a36558`](https://github.com/OZI-Project/ozi-spec/commit/9a3655876248d62296340cfd12ad4ab4e8de9c2a))

## 0.16.0 (2024-12-19)


### Features


* feat: move provider specific CI config into its own key — rjdbcm <rjdbcm@outlook.com>
([`37cb363`](https://github.com/OZI-Project/ozi-spec/commit/37cb363010a169e687522b34484ddf3bba8a8fc2))

## 0.15.4 (2024-12-19)


### Build system


* build(deps): bump OZI-Project/publish from 1.7.1 to 1.7.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.1...1.7.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1437e97`](https://github.com/OZI-Project/ozi-spec/commit/1437e972501680c7e807239041104bd0662978c3))

* build(deps): bump OZI-Project/draft from 1.6.3 to 1.7.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.3 to 1.7.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.3...1.7.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`753312c`](https://github.com/OZI-Project/ozi-spec/commit/753312c33ce4d56eafd2683535e6d0114e84ee40))


### Unknown


* Officially support Python 3.13 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6e64153`](https://github.com/OZI-Project/ozi-spec/commit/6e64153d0171cbfcf08308a403632c33e2ee45e2))

* Create purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`561c762`](https://github.com/OZI-Project/ozi-spec/commit/561c7622066dc153861317f0e30dd883411818e9))

## 0.15.3 (2024-12-17)


### Build system


* build(deps): bump OZI-Project/publish from 1.7.0 to 1.7.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.7.0...1.7.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`945dbbe`](https://github.com/OZI-Project/ozi-spec/commit/945dbbe4c53f7b807017353d05c710d7b1202c69))

* build(deps): bump OZI-Project/draft from 1.6.2 to 1.6.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.2 to 1.6.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.2...1.6.3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cb2fc76`](https://github.com/OZI-Project/ozi-spec/commit/cb2fc76fef586a5dc91b4f9d1008f11e27469e7f))

* build(deps): bump OZI-Project/draft from 1.6.1 to 1.6.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.1 to 1.6.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.1...1.6.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fc9cd28`](https://github.com/OZI-Project/ozi-spec/commit/fc9cd28818f69b72f28bd0967b7c7f2cd9207c04))

## 0.15.2 (2024-12-16)


### Build system


* build(deps): bump OZI-Project/draft from 1.6.0 to 1.6.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.0 to 1.6.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.6.0...1.6.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cc028fe`](https://github.com/OZI-Project/ozi-spec/commit/cc028fe76900e110c321b594b3e99c8d1a229045))

## 0.15.1 (2024-12-16)


### Bug fixes


* fix: add pkg-containers.githubusercontent.com:443 to publish endpoints — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`11c3ade`](https://github.com/OZI-Project/ozi-spec/commit/11c3adee3113d1d4b3a2f7b82735f1612cbeea51))


### Build system


* build(deps): bump OZI-Project/release from 1.1.1 to 1.1.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.1 to 1.1.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.1.1...1.1.2)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`df32964`](https://github.com/OZI-Project/ozi-spec/commit/df329642de097c812d31854df7148dfdcaf83af0))

* build(deps): bump OZI-Project/checkpoint from 1.3.0 to 1.4.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`29a4a69`](https://github.com/OZI-Project/ozi-spec/commit/29a4a6903e9a9596bddd81d0ffc469965a7118db))

* build(deps): bump OZI-Project/release from 1.1.0 to 1.1.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.1.0 to 1.1.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.1.0...1.1.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c556432`](https://github.com/OZI-Project/ozi-spec/commit/c5564329890fcad66700ac455a25232f54fe8ea2))

* build(deps): bump OZI-Project/publish from 1.6.0 to 1.7.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.6.0 to 1.7.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.6.0...1.7.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`23bc5b8`](https://github.com/OZI-Project/ozi-spec/commit/23bc5b852009599c56777d7583c2f5467a35ac7f))

* build(deps): bump OZI-Project/release from 1.0.5 to 1.1.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.5 to 1.1.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.5...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e069286`](https://github.com/OZI-Project/ozi-spec/commit/e069286cbc0f55efdf1164679050498d78f17f54))

* build(deps): bump OZI-Project/checkpoint from 1.2.1 to 1.3.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.3.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.2.1...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8289373`](https://github.com/OZI-Project/ozi-spec/commit/828937334878c6f511c64f9c1ae49ccb497da5e6))


### Unknown


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5cfe14e`](https://github.com/OZI-Project/ozi-spec/commit/5cfe14e5ce3fe7fc61ed0e6f0991b1ef53ebb91a))

* Update dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5dceddf`](https://github.com/OZI-Project/ozi-spec/commit/5dceddf7b0628afcc36d200e4d542c342d749c38))

* Update dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5813c88`](https://github.com/OZI-Project/ozi-spec/commit/5813c882a085145fe4422c2758c534779f8a28d1))

## 0.15.0 (2024-12-16)


### Bug fixes


* fix: add ghcr endpoint
([`1535c2d`](https://github.com/OZI-Project/ozi-spec/commit/1535c2d82614b77ae1011258eced46d882d6a706))

* fix: run isort — rjdbcm <rjdbcm@outlook.com>
([`4b977ff`](https://github.com/OZI-Project/ozi-spec/commit/4b977ff0593d0b7cc59890bc116ee27cc5d6f7fd))

* fix: script name typo — rjdbcm <rjdbcm@outlook.com>
([`7883351`](https://github.com/OZI-Project/ozi-spec/commit/78833511e1632ebcfb665c6728db8bb93a9660af))

* fix: add pypi-publish version getter script — rjdbcm <rjdbcm@outlook.com>
([`61f15e9`](https://github.com/OZI-Project/ozi-spec/commit/61f15e92e7ed9c48ac9f1f4f5cadfbda05f1f1e8))


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.2.1 to 1.3.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.3.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.2.1...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`10874dd`](https://github.com/OZI-Project/ozi-spec/commit/10874dd06387c8973c66ad23d62024b14a60afb8))


### Features


* feat: add checkpoint workflows and separate gh-action-pypi-publish metadata — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`091ac8b`](https://github.com/OZI-Project/ozi-spec/commit/091ac8bbbb3db3594b635606ca513bfd742e3623))


### Performance improvements


* perf: add pipx to ci backend requirements — rjdbcm <rjdbcm@outlook.com>
([`caa7aae`](https://github.com/OZI-Project/ozi-spec/commit/caa7aaebd49271cf73065e2c72a574a6beb17721))

* perf: add gh_action_pypi_publish key to ci for compatibility with gh-action-pypi-publish>1.12.x — rjdbcm <rjdbcm@outlook.com>
([`bba2664`](https://github.com/OZI-Project/ozi-spec/commit/bba26646fdf06121526b6eac56be1504bf8596f3))


### Unknown


* Create dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6b2edf8`](https://github.com/OZI-Project/ozi-spec/commit/6b2edf865428bfad3c4649083de523ec70c255e9))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`68ef656`](https://github.com/OZI-Project/ozi-spec/commit/68ef656681b831acf48c63bfead95ad173458417))

## 0.14.1 (2024-12-10)

## 0.14.0 (2024-12-09)


### Build system


* build(deps): bump OZI-Project/publish from 1.6.0 to 1.6.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.6.0 to 1.6.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.6.0...1.6.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fb018b0`](https://github.com/OZI-Project/ozi-spec/commit/fb018b059bbaa30fcea75ed1c7367a4432696bb1))

* build(deps): update ozi-build[core,uv] requirement

Updates the requirements on [ozi-build[core,uv]](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.7.2...1.8.0)


updated-dependencies:
- dependency-name: ozi-build[core,uv]
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`2042c6b`](https://github.com/OZI-Project/ozi-spec/commit/2042c6bc4ae8ba754e82f4aa774da0a6fac9149e))

* build(deps): bump OZI-Project/draft from 1.5.0 to 1.6.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.5.0...1.6.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`34a0356`](https://github.com/OZI-Project/ozi-spec/commit/34a0356722c74759ba9af08cf2c319857ab8e55a))

* build(deps): bump OZI-Project/publish from 1.5.0 to 1.6.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.5.0...1.6.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f189b19`](https://github.com/OZI-Project/ozi-spec/commit/f189b19ab9810690b3aecf86c3478c1954ad26fb))


### Features


* feat: semantic-release~=9.15

build(deps): bump OZI-Project/draft from 1.5.0 to 1.6.0
([`6a76fbe`](https://github.com/OZI-Project/ozi-spec/commit/6a76fbe97f9e207739f26163facd2cc2a8b8f7c4))


### Performance improvements


* perf: OZI.build~=1.8.0 in ``ci.py`` — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`2209653`](https://github.com/OZI-Project/ozi-spec/commit/2209653bd3d270064d4df072a739894112e2f54e))

## 0.13.1 (2024-12-06)


### Performance improvements


* perf: OZI.build~=1.7.2 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c3658fc`](https://github.com/OZI-Project/ozi-spec/commit/c3658fc00802c7c3f964800fc66d99680ddf1767))


### Unknown


* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c26965c`](https://github.com/OZI-Project/ozi-spec/commit/c26965c7db7452cce5c1f7d4446647704cdf2c88))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`28b6486`](https://github.com/OZI-Project/ozi-spec/commit/28b64864809351d08e5273954c93feed80448e44))

## 0.13.0 (2024-11-30)


### Features


* feat: bump to workaround CI issues — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`e8862ca`](https://github.com/OZI-Project/ozi-spec/commit/e8862ca24287b23d3e8dcac191d7c71ed42f7488))


### Unknown


* Update ozi.wrap — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8729fc2`](https://github.com/OZI-Project/ozi-spec/commit/8729fc2567d65eebf324f557faccdc0f2a2c7257))

## 0.12.3 (2024-11-28)


### Build system


* build(ozi.wrap): OZI 1.25 subproject — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`aad551a`](https://github.com/OZI-Project/ozi-spec/commit/aad551abbb8a05e278bfdcfdf65565ba8865d9b5))

* build: update license metadata — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f11aa58`](https://github.com/OZI-Project/ozi-spec/commit/f11aa589d80700fed2389d6dc26a610126d16fa3))

* build: update license to MIT-0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4c1c8c1`](https://github.com/OZI-Project/ozi-spec/commit/4c1c8c14450c5e01fd8ae982011cd3155df10cb0))

## 0.12.2 (2024-11-20)


### Build system


* build: allow build patch tag — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a943072`](https://github.com/OZI-Project/ozi-spec/commit/a943072e3f09f6616dc1c59f10c5128301ce69ba))

* build(deps): bump step-security/harden-runner from 2.10.1 to 2.10.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.1 to 2.10.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/91182cccc01eb5e619899d80e4e971d6181294a7...0080882f6c36860b6ba35c610c98ce87d4e2f26f)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`48d7243`](https://github.com/OZI-Project/ozi-spec/commit/48d72433f714df7f910541d3bbec4af7047336d1))

## 0.12.1 (2024-11-18)


### Bug fixes


* fix: typing of default value getter — rjdbcm <rjdbcm@outlook.com>
([`9b8ad40`](https://github.com/OZI-Project/ozi-spec/commit/9b8ad4041cb109205fe90ed70babdbbbdd640b0b))


### Performance improvements


* perf: add harden_runner version info to metadata — rjdbcm <rjdbcm@outlook.com>
([`7d77b7d`](https://github.com/OZI-Project/ozi-spec/commit/7d77b7d6e432552c998502e20bfcdce368393527))


### Unknown


* run black — rjdbcm <rjdbcm@outlook.com>
([`39a5288`](https://github.com/OZI-Project/ozi-spec/commit/39a5288545ed05acf49fa0abfd3d2e53e8b48123))

## 0.12.0 (2024-11-15)


### Bug fixes


* fix: comment out nested dependencies incompatible with dependabot — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1436e82`](https://github.com/OZI-Project/ozi-spec/commit/1436e82fdbb93dc6fb0bf7d91f13bdb56fcd7d9e))


### Build system


* build(deps): bump OZI-Project/draft from 1.4.1 to 1.5.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.4.1...1.5.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`742bccf`](https://github.com/OZI-Project/ozi-spec/commit/742bccf26a4f66651e33a0360167d4b7e1bcb3e8))

* build(deps): bump OZI-Project/release from 1.0.4 to 1.0.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.4 to 1.0.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.4...1.0.5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9367667`](https://github.com/OZI-Project/ozi-spec/commit/9367667155f16a91996053c52865d17f471e7a16))

* build(deps): bump OZI-Project/publish from 1.4.1 to 1.5.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.1...1.5.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b28f25f`](https://github.com/OZI-Project/ozi-spec/commit/b28f25f1daa8f7d3f850107a08a6f00170a3baf7))


### Features


* feat: python-semantic-release~=9.14.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`533aa27`](https://github.com/OZI-Project/ozi-spec/commit/533aa27a9db840b70b7b63e0c6974eba8a91c2c0))


### Performance improvements


* perf: OZI 1.24  — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9cd3fc8`](https://github.com/OZI-Project/ozi-spec/commit/9cd3fc86c6837bcbf1f8435fcca1f31004e06d89))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1afb475`](https://github.com/OZI-Project/ozi-spec/commit/1afb4750d118b99ae0991a0e33ddcc82d5d27841))

## 0.11.7 (2024-11-14)


### Performance improvements


* perf: add provenance key to ci — rjdbcm <rjdbcm@outlook.com>
([`a669e0e`](https://github.com/OZI-Project/ozi-spec/commit/a669e0edb36bce5229d445c537abbfef64eceed1))

## 0.11.6 (2024-11-14)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.1.1 to 1.2.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.1 to 1.2.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.1.1...1.2.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`876aeed`](https://github.com/OZI-Project/ozi-spec/commit/876aeed60bec1c28eaa162b9a2a7f327cf4b4d39))

* build(deps): bump OZI-Project/draft from 1.4.0 to 1.4.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.4.0...1.4.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f634155`](https://github.com/OZI-Project/ozi-spec/commit/f634155c25ee0d95e78fbb5103a1dd655aaff2cd))


### Performance improvements


* perf: always use the same workflow versions as build — rjdbcm <rjdbcm@outlook.com>
([`8692e01`](https://github.com/OZI-Project/ozi-spec/commit/8692e018ea2933048b861a927e4ece248bb38562))

## 0.11.5 (2024-11-06)


### Bug fixes


* fix: pin OZI-Project/publish to 1.4.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8a01455`](https://github.com/OZI-Project/ozi-spec/commit/8a01455597abde3a4fa729504f36923b6d9998a4))


### Build system


* build(deps): bump OZI-Project/publish from 1.4.0 to 1.4.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.4.0...1.4.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f9c42b2`](https://github.com/OZI-Project/ozi-spec/commit/f9c42b2f9dc0e9e07bfde1d38fedc894ec9a1345))


### Unknown


* :lock: update publish workflow endpoints — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`acab398`](https://github.com/OZI-Project/ozi-spec/commit/acab398e8c6544a16c6bbffc813b966899364496))

## 0.11.4 (2024-10-28)


### Bug fixes


* fix: add coverage deferall — rjdbcm <rjdbcm@outlook.com>
([`fc1ff36`](https://github.com/OZI-Project/ozi-spec/commit/fc1ff36e9e869290053255d1a4c187703ace939a))

* fix: Liskov substition violation — rjdbcm <rjdbcm@outlook.com>
([`03ee532`](https://github.com/OZI-Project/ozi-spec/commit/03ee532cb7646be7e17e95d29a0e60d8633e40ad))

* fix: use int to calculate ozi version from spec — rjdbcm <rjdbcm@outlook.com>
([`c48b18d`](https://github.com/OZI-Project/ozi-spec/commit/c48b18d6d33876a545d200f64a4c49164bebe9af))

## 0.11.3 (2024-10-28)


### Bug fixes


* fix: run black — rjdbcm <rjdbcm@outlook.com>
([`e7cae93`](https://github.com/OZI-Project/ozi-spec/commit/e7cae93c4a7c52f03c5ca908ac465c444492e36c))

* fix: remove hardcoded version string, OZI version now a set interval ahead of ozi-spec version — rjdbcm <rjdbcm@outlook.com>
([`d304976`](https://github.com/OZI-Project/ozi-spec/commit/d304976a24c0df92c7f49aa4890a152abaccc7c7))

## 0.11.2 (2024-10-28)


### Bug fixes


* fix: update spec target version to 1.24 — rjdbcm <rjdbcm@outlook.com>
([`e22297d`](https://github.com/OZI-Project/ozi-spec/commit/e22297d2441d173f1b3348ad4e5769f3d977b1f6))


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.0.2 to 1.1.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.2 to 1.1.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.2...1.1.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`667f0b1`](https://github.com/OZI-Project/ozi-spec/commit/667f0b191e42db2e817628608cf1d2409d0e7b22))

## 0.11.1 (2024-10-25)


### Bug fixes


* fix: OZI-Project/checkpoint 1.1.1

only build wheel if cibuildwheel passes — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4cbd408`](https://github.com/OZI-Project/ozi-spec/commit/4cbd408afb280371f43b417bee6fafd864dac05c))

## 0.11.0 (2024-10-25)


### Features


* feat: OZI-Project/checkpoint 1.1.0 - build is checkpointed as well — rjdbcm <rjdbcm@outlook.com>
([`4b69eee`](https://github.com/OZI-Project/ozi-spec/commit/4b69eee05015be1d11ccf8b3df6033685e82c9b6))

## 0.10.9 (2024-10-23)


### Performance improvements


* perf: refactor types and remove undocumented requirement on typing_extensions for Python < 3.11 — rjdbcm <rjdbcm@outlook.com>
([`eb247d6`](https://github.com/OZI-Project/ozi-spec/commit/eb247d69a84b9c2911a7fc21bb685ffa8285b766))

## 0.10.8 (2024-10-18)


### Build system


* build(deps): bump OZI-Project/draft from 1.3.0 to 1.4.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e4551a9`](https://github.com/OZI-Project/ozi-spec/commit/e4551a92f989d139a2afd0040ec5cb0610bc763f))

* build(deps): bump OZI-Project/publish from 1.3.0 to 1.4.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.3.0...1.4.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f51b896`](https://github.com/OZI-Project/ozi-spec/commit/f51b8962216d9d6c9f9d186fc7d055e60cd044d6))

* build(deps): bump OZI-Project/publish from 1.2.2 to 1.3.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.2.2 to 1.3.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.2.2...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b73d3dc`](https://github.com/OZI-Project/ozi-spec/commit/b73d3dc64ab7f1f9a9db3fbc33389e66ee9c83d0))

* build(deps): bump OZI-Project/draft from 1.2.2 to 1.3.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.2.2 to 1.3.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.2.2...1.3.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2a2c76d`](https://github.com/OZI-Project/ozi-spec/commit/2a2c76ddec43e93ca5dbb22c66165a63c4872250))


### Performance improvements


* perf(semantic-release): update draft and publish to 1.4.0

semantic-release 9.12 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8c86e97`](https://github.com/OZI-Project/ozi-spec/commit/8c86e97b44be1a4c7fd189562b099b5e7b856927))

## 0.10.7 (2024-10-14)


### Bug fixes


* fix: bump OZI version to 1.23 — rjdbcm <rjdbcm@outlook.com>
([`24b3055`](https://github.com/OZI-Project/ozi-spec/commit/24b3055b73f8af6d3dafdb84bb3b23a707e5023d))

## 0.10.6 (2024-10-14)


### Bug fixes


* fix: stubfile typo — rjdbcm <rjdbcm@outlook.com>
([`f4d0952`](https://github.com/OZI-Project/ozi-spec/commit/f4d09523e062c448a26d2327ed661a87bbc41651))

## 0.10.5 (2024-10-14)


### Bug fixes


* fix: missing py.typed — rjdbcm <rjdbcm@outlook.com>
([`d179e58`](https://github.com/OZI-Project/ozi-spec/commit/d179e58efb33c7755efb98ba80c3e74a71e5e8c3))

## 0.10.4 (2024-10-14)


### Build system


* build(deps): bump OZI-Project/release from 1.0.3 to 1.0.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.3 to 1.0.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.3...1.0.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`dac7049`](https://github.com/OZI-Project/ozi-spec/commit/dac7049f05290ce1b391ad3d22c67cdf455aaa09))

* build(deps): bump OZI-Project/checkpoint from 1.0.1 to 1.0.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.1...1.0.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad7e8bb`](https://github.com/OZI-Project/ozi-spec/commit/ad7e8bbf1720e793062f55627a6473ecc0a85680))

* build(deps): bump OZI-Project/draft from 1.1.0 to 1.2.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.1.0 to 1.2.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.1.0...1.2.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c6cc3cb`](https://github.com/OZI-Project/ozi-spec/commit/c6cc3cb56e3d9eba5c938327c05db9268e7a9486))

* build(deps): bump OZI-Project/publish from 1.1.0 to 1.2.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.1.0 to 1.2.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.1.0...1.2.2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d1f806c`](https://github.com/OZI-Project/ozi-spec/commit/d1f806cc5fcc0a81dea7218296cd59f804a3fd48))


### Performance improvements


* perf: publish and draft 1.2.2, checkpoint 1.0.2, release 1.0.4 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8f3a1b4`](https://github.com/OZI-Project/ozi-spec/commit/8f3a1b4da5b1ad5f4aee6ea7c96dcaa23e830a8f))

## 0.10.3 (2024-10-14)


### Build system


* build: increase lint timeout — rjdbcm <rjdbcm@outlook.com>
([`7b5de9e`](https://github.com/OZI-Project/ozi-spec/commit/7b5de9e4037b95ebb745283c1a7eb3a3f15c5c00))


### Performance improvements


* perf: add typing stubfiles — rjdbcm <rjdbcm@outlook.com>
([`2feefa5`](https://github.com/OZI-Project/ozi-spec/commit/2feefa55a57944b8360141ba6b2a7dd494ab3bd1))

## 0.10.2 (2024-10-08)


### Bug fixes


* fix: skip flaky 3.13 checkpoint for now — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`30cae94`](https://github.com/OZI-Project/ozi-spec/commit/30cae94cdab98cb2d4f987ea11e4727898d81902))

* fix: add no cover — rjdbcm <rjdbcm@outlook.com>
([`b16adcc`](https://github.com/OZI-Project/ozi-spec/commit/b16adccc9677ae59443208b220be491844da66a3))

* fix: set default loop scope for async tests — rjdbcm <rjdbcm@outlook.com>
([`4263f39`](https://github.com/OZI-Project/ozi-spec/commit/4263f3947efaeef8de5deca63bab43be76e3e62a))


### Build system


* build: double the timeout for lint suite — rjdbcm <rjdbcm@outlook.com>
([`6b084a7`](https://github.com/OZI-Project/ozi-spec/commit/6b084a7a9ad90748c09919478cbc09aa8470c698))

* build(deps): bump OZI-Project/publish from 1.0.1 to 1.1.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.1 to 1.1.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.1...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a2c8d4a`](https://github.com/OZI-Project/ozi-spec/commit/a2c8d4ac76bbb4145bc1c60e93482d3143e22227))

* build(deps): bump OZI-Project/draft from 1.0.1 to 1.1.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.1 to 1.1.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.1...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f9f3931`](https://github.com/OZI-Project/ozi-spec/commit/f9f3931265f547e9e97268e53652bcdc57a163be))

* build(deps): bump OZI-Project/release from 1.0.1 to 1.0.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.1 to 1.0.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.1...1.0.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e40bb18`](https://github.com/OZI-Project/ozi-spec/commit/e40bb183eaac8ad091d70f4762ed09d40f2246c4))


### Performance improvements


* perf: deprecate Python 3.10 checkpoint — rjdbcm <rjdbcm@outlook.com>
([`9704e07`](https://github.com/OZI-Project/ozi-spec/commit/9704e07b5f8ff0b55d1d83b276e5784969612c0f))

* perf: release and draft v1.1 - semantic-release 9.9 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`37bb25f`](https://github.com/OZI-Project/ozi-spec/commit/37bb25f95de43a4463cfd7e904a9a4b08091df96))

## 0.10.1 (2024-09-27)


### Build system


* build(deps): bump OZI-Project/publish from 1.0.0 to 1.0.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e5d05cf`](https://github.com/OZI-Project/ozi-spec/commit/e5d05cf7ba1d7cf66a25642ead9af3ea909960d5))

* build(deps): bump OZI-Project/release from 1.0.0 to 1.0.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d3bdd18`](https://github.com/OZI-Project/ozi-spec/commit/d3bdd18d6fa6e7cf33bbdf8c3b09283faba7bcc4))

* build(deps): bump OZI-Project/draft from 1.0.0 to 1.0.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`27355f4`](https://github.com/OZI-Project/ozi-spec/commit/27355f4679ee0eaa2130971eb3b5d81bb4a06b48))

* build(deps): bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8c22a9d`](https://github.com/OZI-Project/ozi-spec/commit/8c22a9dceecf66602b7becef1c9fa703323f07be))


### Performance improvements


* perf: pin all github CI workflows to 1.0.0 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`76d32e5`](https://github.com/OZI-Project/ozi-spec/commit/76d32e5c401ccdd4b15f8ea603abd23aa78139b0))


### Unknown


* Release (#82)

* build(deps): bump OZI-Project/publish from 1.0.0 to 1.0.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] <support@github.com>

* build(deps): bump OZI-Project/release from 1.0.0 to 1.0.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] <support@github.com>

* build(deps): bump OZI-Project/draft from 1.0.0 to 1.0.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] <support@github.com>

* build(deps): bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] <support@github.com>

* perf: pin all github CI workflows to 1.0.1

Signed-off-by: Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>



Signed-off-by: dependabot[bot] <support@github.com>
Signed-off-by: Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
([`7bb2796`](https://github.com/OZI-Project/ozi-spec/commit/7bb27960bd0bfe22742114f0ed24df57d47f6980))

## 0.10.0 (2024-09-16)

## 0.9.5 (2024-09-10)

## 0.9.4 (2024-09-06)


### Bug fixes


* fix: add RUF200 to tool.ruff.lint ignores — rjdbcm <rjdbcm@outlook.com>
([`4a648e3`](https://github.com/OZI-Project/ozi-spec/commit/4a648e3c3660c9e0063bc85cca3d0aa608968d69))

* fix: draft@0.3.11 and release@0.8.11 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`9d81f33`](https://github.com/OZI-Project/ozi-spec/commit/9d81f33f232997ffb914a05dd52a0f80ecdf2c24))


### Build system


* build(deps): bump step-security/harden-runner from 2.9.1 to 2.10.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.1 to 2.10.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde...91182cccc01eb5e619899d80e4e971d6181294a7)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`892e9ea`](https://github.com/OZI-Project/ozi-spec/commit/892e9eab007fe6fbf486f0b52903348564045a4e))

* build(deps): bump OZI-Project/release from 0.8.11 to 1.0.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`8fa5549`](https://github.com/OZI-Project/ozi-spec/commit/8fa5549d68d91feb6b028139b4bb2015ae5ac4cb))

* build(deps): bump OZI-Project/publish from 0.1.11 to 1.0.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`6232a10`](https://github.com/OZI-Project/ozi-spec/commit/6232a1057ba0eb2eb9ec5d59004d20f6e6487b51))

* build(deps): bump OZI-Project/draft from 0.3.11 to 1.0.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`3e19eda`](https://github.com/OZI-Project/ozi-spec/commit/3e19eda33d3bb0c3143dd322cddebcc7151dc3a3))

* build(deps): bump OZI-Project/checkpoint from 0.5.2 to 1.0.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.2 to 1.0.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.2...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`a0cb42b`](https://github.com/OZI-Project/ozi-spec/commit/a0cb42b98d6030e3966d132a487eb6527e19e620))

* build(deps): bump OZI-Project/draft from 0.3.10 to 0.3.11

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.10 to 0.3.11.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.10...0.3.11)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4295af1`](https://github.com/OZI-Project/ozi-spec/commit/4295af1d55822cbacd0def7759c9d0e9c43e834b))

* build(deps): bump OZI-Project/release from 0.8.10 to 0.8.11

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.10 to 0.8.11.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.10...0.8.11)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4061f90`](https://github.com/OZI-Project/ozi-spec/commit/4061f9066bdb3f59108a66a887ff75bf7a09cfba))

* build(deps): bump OZI-Project/draft from 0.3.9 to 0.3.10

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.9 to 0.3.10.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.9...0.3.10)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e0b459f`](https://github.com/OZI-Project/ozi-spec/commit/e0b459f68771d57b70c9c160e49d526029d8b4b2))

* build(deps): bump OZI-Project/publish from 0.1.10 to 0.1.11

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.10 to 0.1.11.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.10...0.1.11)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`abed060`](https://github.com/OZI-Project/ozi-spec/commit/abed060ff01055797baf5f50edaac0606aca2a0e))


### Features


* feat: move cibuildwheel and twine to utility apps — rjdbcm <rjdbcm@outlook.com>
([`e33e5ec`](https://github.com/OZI-Project/ozi-spec/commit/e33e5ecb0ceb9f08c513a0d83e225a5346f9778d))


### Performance improvements


* perf: Python 3.13 support — rjdbcm <rjdbcm@outlook.com>
([`efb9c24`](https://github.com/OZI-Project/ozi-spec/commit/efb9c2447a33e5346f91387399914327b748bc31))

* perf: pin all github CI workflows to 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`c66e60a`](https://github.com/OZI-Project/ozi-spec/commit/c66e60ae88c726b24bdddeb27f209a1a7c6d345f))

* perf: OZI-Project/draft@0.3.10 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`2638fe5`](https://github.com/OZI-Project/ozi-spec/commit/2638fe52f47bf60a12f23bfdc5e06d73fa05d537))

* perf: OZI-Project/publish@0.1.11 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`10d88fe`](https://github.com/OZI-Project/ozi-spec/commit/10d88fe77084d5fc4034f1c82ddf67f73e179df1))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`6cc96b0`](https://github.com/OZI-Project/ozi-spec/commit/6cc96b03afee014b9a87d1fa9d2b1416e3d97b50))

## 0.9.3 (2024-09-02)


### Bug fixes


* fix: patch release trigger

Merge pull request #58 from OZI-Project/main
([`10e8ae0`](https://github.com/OZI-Project/ozi-spec/commit/10e8ae0bb90dd8bfad12a152d98a86c2dbc91ded))


### Build system


* build(deps): OZI.build~=1.5 — rjdbcm <rjdbcm@outlook.com>
([`29f7da6`](https://github.com/OZI-Project/ozi-spec/commit/29f7da69efc5685e2ff22250f0fd0cf241b45c36))

## 0.9.2 (2024-08-30)


### Bug fixes


* fix(pkg.py): remove requirements.in and add .gitignore — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`3f856f9`](https://github.com/OZI-Project/ozi-spec/commit/3f856f9ceb7631c95ba4330fe5ee785e9efb6250))

## 0.9.1 (2024-08-28)


### Bug fixes


* fix: correct key typo — rjdbcm <rjdbcm@outlook.com>
([`0805bac`](https://github.com/OZI-Project/ozi-spec/commit/0805bacc3f17c982acc362aee1ce8734f6b04339))

* fix: project-url to project-urls list — rjdbcm <rjdbcm@outlook.com>
([`5871986`](https://github.com/OZI-Project/ozi-spec/commit/58719861cb8cf5f2f27bf35a9d7ced44ffe42c88))

* fix: update pyproject.toml for OZI 1.20 — rjdbcm <rjdbcm@outlook.com>
([`881b79a`](https://github.com/OZI-Project/ozi-spec/commit/881b79aa722ba215c60a559cf23cb9886a878d90))


### Performance improvements


* perf: OZI.build[core]~=1.4.3 — rjdbcm <rjdbcm@outlook.com>
([`ed66155`](https://github.com/OZI-Project/ozi-spec/commit/ed66155c592a98b28a31e38de4e7218d2414039e))

## 0.9.0 (2024-08-27)


### Features


* feat: remove requirements.in target OZI.build 1.3 — rjdbcm <rjdbcm@outlook.com>
([`7cf50c3`](https://github.com/OZI-Project/ozi-spec/commit/7cf50c36db9266c65a83e7f19d4f93e7e92e732d))

## 0.8.1 (2024-08-23)


### Bug fixes


* fix: pin spec to 0.8 and OZI to 1.19 — rjdbcm <rjdbcm@outlook.com>
([`54718a3`](https://github.com/OZI-Project/ozi-spec/commit/54718a326cffd2e8494d9dea6fc6ae6e91cdc9d2))

## 0.8.0 (2024-08-23)

## 0.7.0 (2024-08-22)


### Build system


* build(deps): bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`82eec52`](https://github.com/OZI-Project/ozi-spec/commit/82eec52f2529583143254b00b602c1d82fe7ef4d))

* build(deps): bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c4926bc`](https://github.com/OZI-Project/ozi-spec/commit/c4926bc1b82a5217c9f0e56fdd5e868962b0e2ed))

* build(deps): bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1b46763`](https://github.com/OZI-Project/ozi-spec/commit/1b46763411561d769d696ec9fe819c750ccadc92))

* build(deps): bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.9...0.8.10)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9a18441`](https://github.com/OZI-Project/ozi-spec/commit/9a1844126123239242f7a4af5aab989025ecf02b))


### Features


* feat: OZI.build renders optional_dependencies — rjdbcm <rjdbcm@outlook.com>
([`f8f5088`](https://github.com/OZI-Project/ozi-spec/commit/f8f50889523cd26362001821d77dbe94df9692f1))

* feat: add invoke to build-system deps

also patches github workflows — rjdbcm <rjdbcm@outlook.com>
([`fa7e9cf`](https://github.com/OZI-Project/ozi-spec/commit/fa7e9cfbaa34d5562d4d1be24f5f12774fc735da))

## 0.6.1 (2024-08-16)


### Bug fixes


* fix: Merge pull request #41 from OZI-Project/0.6

0.6
([`0132861`](https://github.com/OZI-Project/ozi-spec/commit/0132861b435a6a2159ec2c4a63cc786359efc494))


### Unknown


* :pencil2: OZI 1.18 and spec 0.6 pin versions — rjdbcm <rjdbcm@outlook.com>
([`7992390`](https://github.com/OZI-Project/ozi-spec/commit/79923901da0352a028ffcc010904ed2185caf3f0))

## 0.6.0 (2024-08-16)


### Features


* feat: added ``cibuildwheel`` and ``twine`` as plugins

Also pins pip-tools~=7.4, OZI.build~=1.0.2, tox~=4.18, tox-gh~=1.3 — rjdbcm <rjdbcm@outlook.com>
([`02062f1`](https://github.com/OZI-Project/ozi-spec/commit/02062f1fbf2a8d1750bab9e3855152eeb7d118e6))


### Unknown


* :rotating_light: run black — rjdbcm <rjdbcm@outlook.com>
([`abf9aa2`](https://github.com/OZI-Project/ozi-spec/commit/abf9aa2902c8a77b032a9aa3457226942599f5ec))

## 0.5.10 (2024-08-12)


### Build system


* build(deps): bump OZI-Project/release from 0.7.4 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.9)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`268f056`](https://github.com/OZI-Project/ozi-spec/commit/268f0564ec46b9e561a8358b480cc3d42f003b1c))

* build(deps): bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cc6207c`](https://github.com/OZI-Project/ozi-spec/commit/cc6207cc12c76bbec4f3f3e18041dd36456d089e))

* build(deps): bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7263fec`](https://github.com/OZI-Project/ozi-spec/commit/7263fec1eea67c623fa65c798e0f8e1b1b2df2f3))

* build(deps): bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`821e408`](https://github.com/OZI-Project/ozi-spec/commit/821e4084616885747547bcf332a7adad26f0cd1e))

* build(deps): bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4886f1f`](https://github.com/OZI-Project/ozi-spec/commit/4886f1f45ba30e4c61906322c5673bbf7413a25e))


### Performance improvements


* perf(ci.py): Release version=0.8.9 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`8d7e85c`](https://github.com/OZI-Project/ozi-spec/commit/8d7e85c67c83c7b6ee92e1b6a166d7785b8b7d6e))

## 0.5.9 (2024-08-05)


### Performance improvements


* perf: Bump OZI-Project/draft from 0.3.7 to 0.3.8 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b4422c2`](https://github.com/OZI-Project/ozi-spec/commit/b4422c232cd3e91bc829d17475418d93bab5ac71))

* perf: Bump OZI-Project/release from 0.7.3 to 0.7.4 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b97460b`](https://github.com/OZI-Project/ozi-spec/commit/b97460b613a7d397b160cf4430b55b17b18a45d9))

* perf: Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`b2369f7`](https://github.com/OZI-Project/ozi-spec/commit/b2369f7bdeae8881de0b73a0b8bf86e7dc74b120))

## 0.5.8 (2024-07-29)


### Performance improvements


* perf: draft 0.3.7 — rjdbcm <rjdbcm@outlook.com>
([`9356eec`](https://github.com/OZI-Project/ozi-spec/commit/9356eecbfd41c2c59f0eb821051e5c0c871293f4))

* perf: publish 0.1.9 — rjdbcm <rjdbcm@outlook.com>
([`c5fbfcb`](https://github.com/OZI-Project/ozi-spec/commit/c5fbfcb46b50f8212c28ecb5d2def521179e45a9))

## 0.5.7 (2024-07-25)


### Bug fixes


* fix: OZI default version 1.17 — rjdbcm <rjdbcm@outlook.com>
([`018880d`](https://github.com/OZI-Project/ozi-spec/commit/018880de8601b6930aef6a26d0e59f8a772700e6))


### Build system


* build(deps): bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6ad4dff`](https://github.com/OZI-Project/ozi-spec/commit/6ad4dff4be252202a93f012b009ed43a4f324086))

* build(deps): bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`731cd8e`](https://github.com/OZI-Project/ozi-spec/commit/731cd8e0fba988578d0017af49140c179262afc2))

## 0.5.6 (2024-07-22)


### Bug fixes


* fix: correct ``templates/templates/*`` names to include ``.j2`` extension
([`cf1094e`](https://github.com/OZI-Project/ozi-spec/commit/cf1094e8e598afdd62e1d90a87415b699e2bf2a5))

## 0.5.5 (2024-07-19)


### Bug fixes


* fix: use sigstore-v3 actions in github CI — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`d45030f`](https://github.com/OZI-Project/ozi-spec/commit/d45030ffefea9496ed296614451e5ea7e15d97cf))

## 0.5.4 (2024-07-18)


### Build system


* build(deps): bump OZI-Project/release from 0.6.5 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`15ac435`](https://github.com/OZI-Project/ozi-spec/commit/15ac4353be38569289103aed8404f3e9bb1601a1))

* build(deps): bump OZI-Project/checkpoint from 0.4.2 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`770d374`](https://github.com/OZI-Project/ozi-spec/commit/770d374d80d8690502aa6337846896a62546f197))

* build(deps): bump OZI-Project/draft from 0.3.3 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.3...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`219a326`](https://github.com/OZI-Project/ozi-spec/commit/219a326e38ea6d4e63e458e0ff493d4a098d6f50))

* build(deps): bump step-security/harden-runner from 2.8.0 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.8.0...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f98d0e8`](https://github.com/OZI-Project/ozi-spec/commit/f98d0e8a55cfcf6cc30f3363d5ce94ee21ac2290))

* build(deps): bump OZI-Project/publish from 0.1.6 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.6...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`751407a`](https://github.com/OZI-Project/ozi-spec/commit/751407ab63ad8a2cdbc133b5e392efe29385974c))


### Performance improvements


* perf: Merge pull request #19 from OZI-Project/feature/sigstore-v3

Feature/sigstore v3
([`65f6b21`](https://github.com/OZI-Project/ozi-spec/commit/65f6b216257474dda90fc8a47eb285bd8841f63d))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`88c5e71`](https://github.com/OZI-Project/ozi-spec/commit/88c5e716e0e82ea2ac0d98dc6dff312d74dc93b2))

* Create dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`a5c8af8`](https://github.com/OZI-Project/ozi-spec/commit/a5c8af8b6d8e72f4a57433ef2c1052ffdb296113))

## 0.5.3 (2024-07-18)


### Bug fixes


* fix: OZI.build>=0.0.27 — rjdbcm <rjdbcm@outlook.com>
([`4fd6a01`](https://github.com/OZI-Project/ozi-spec/commit/4fd6a0120d4ccf080d6ec21540874931d4bca0bd))

## 0.5.2 (2024-07-16)


### Performance improvements


* perf: OZI-Project/draft@0.3.5 — rjdbcm <rjdbcm@outlook.com>
([`6344e19`](https://github.com/OZI-Project/ozi-spec/commit/6344e1920ea5e033c062c62bba4a3e7ec70cbcad))

* perf: OZI-Project/checkpoint@0.4.3 — rjdbcm <rjdbcm@outlook.com>
([`37f3cdb`](https://github.com/OZI-Project/ozi-spec/commit/37f3cdba726c2c921762bac49bad2e38aac3353c))

* perf: OZI-Project/release@0.6.6 — rjdbcm <rjdbcm@outlook.com>
([`49a6d93`](https://github.com/OZI-Project/ozi-spec/commit/49a6d939d5e2808c1de1205974c6c90fd8db4b0e))

* perf: OZI-Project/publish@0.1.8 — rjdbcm <rjdbcm@outlook.com>
([`1699c50`](https://github.com/OZI-Project/ozi-spec/commit/1699c5023b492fe2ed49d7340c702abd74f14789))

## 0.5.1 (2024-07-11)


### Bug fixes


* fix: update version — rjdbcm <rjdbcm@outlook.com>
([`158212b`](https://github.com/OZI-Project/ozi-spec/commit/158212baf2061b55a99c556bc0f1862498ba16ac))

## 0.5.0 (2024-07-07)


### Performance improvements


* perf: run black — rjdbcm <rjdbcm@outlook.com>
([`a2f0bc8`](https://github.com/OZI-Project/ozi-spec/commit/a2f0bc8356204624cbbf719f363272ef7531e1ed))

## 0.4.1 (2024-07-01)

## 0.4.0 (2024-07-01)


### Bug fixes


* fix: update commit parser templates — rjdbcm <rjdbcm@outlook.com>
([`4975a1c`](https://github.com/OZI-Project/ozi-spec/commit/4975a1cc3e3e10b38cae41e5584b92649505eb4e))

* fix: individual file license/copyright header corrected to Unlicense
([`74ff29c`](https://github.com/OZI-Project/ozi-spec/commit/74ff29cc0ea4e991cddffd1da6f553eb1fbb40a8))

* fix: doc and download link metadata — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`8c849f6`](https://github.com/OZI-Project/ozi-spec/commit/8c849f692a566ff65499712f38e3b10da86b1dc8))


### Continuous integration


* ci: add 0.x branch pattern — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`5d606c8`](https://github.com/OZI-Project/ozi-spec/commit/5d606c850a9316b1b9f7ecf0cc7c9897b82f6fa1))


### Features


* feat(src.py SrcTemplate): add ``templates``, ``subprojects`` and modified ``ci_provider`` to be a dictionary of tuples — rjdbcm <rjdbcm@outlook.com>
([`6dbd31c`](https://github.com/OZI-Project/ozi-spec/commit/6dbd31c9f0a1053ed0b544c954cc71c20bf150b3))

* feat: tag OZI 1.14
([`b6cb028`](https://github.com/OZI-Project/ozi-spec/commit/b6cb0285901d95512e7545c06edd7f2c539c4125))


### Performance improvements


* perf: OZI-Project/draft@0.3.4 — rjdbcm <rjdbcm@outlook.com>
([`e747e9b`](https://github.com/OZI-Project/ozi-spec/commit/e747e9b1c5caeb5c54c51f66a30eab7b57850878))

* perf: OZI-Project/publish@0.1.7 — rjdbcm <rjdbcm@outlook.com>
([`c224b07`](https://github.com/OZI-Project/ozi-spec/commit/c224b078da4060195d040dec97abb58ca12fb057))


### Unknown


* Update requirements.in — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`a0bcce3`](https://github.com/OZI-Project/ozi-spec/commit/a0bcce34cf6ba9abfd1bdc0685ae9d6c62a7c742))

## 0.3.0 (2024-07-01)


### Features


* feat: init from OZI 1.13.31 spec submodule source
([`434d1db`](https://github.com/OZI-Project/ozi-spec/commit/434d1db4aff6652cd9b88002d18c4d14f55cbd0d))
